@@ -7,7 +7,7 @@ from dataclasses import asdict, field, fields, is_dataclass, make_dataclass, _ge
 from datetime import datetime
 from typing import Any, Optional
 
-from supermodels.exceptions import ValidationError
+from supermodels.exceptions import ImmutableFieldError, ValidationError
 from supermodels.fields import (
     FieldTypeChecker,
     ImmutableDict,
@@ -281,8 +281,24 @@ def raise_validation_error(self, msg: str) -> None:
     raise ValidationError(self, msg)
 
 
+def validate_update_request(self, **kwargs):
+    """Validates an update request against any immutable fields."""
+    immutables = {
+        field.name for field in fields(self) if field.metadata.get("immutable")
+    }
+
+    updated = set(kwargs)
+    illegal = immutables.intersection(updated)
+
+    if illegal:
+        msg = "Attempted to update immutable field(s): " f"{','.join(illegal)}"
+        raise ImmutableFieldError(self, msg)
+
+
 def update(self, **kwargs):
     """Returns an copy of the model with updated attributes."""
+    validate_update_request(self, **kwargs)
+
     data = {field.name: getattr(self, field.name) for field in fields(self)}
 
     data.update(kwargs)
